@@ -39,12 +39,19 @@ class Address(str):
         """
         Address objects are equal if their e-mail address are equal. (Their real names might differ.)
         Address object is equal to a string if the string contains its e-mail address or the whole representation.
-        Example: "person@example.com" == Address("John <person@example.com>") == "John <person@example.com>"  # True
+        Example: "person@EXAMPLE.com" == Address("John <person@example.com>") == "John <person@example.com>"  # True
         """
-        return hash(self) == hash(other) or hash(str(self)) == hash(other)
+        s = hash(other.casefold())
+        return hash(self) == s or hash(str(self).casefold()) == s
+
+    def casefold(self) -> "Address":
+        """ When comparing Addresses, use casefolded version. Important for Address.__eq__
+         (if retyped to a string, we could not compare addresses via Address.__hash__)"""
+        return Address(str(self).casefold())
 
     def __hash__(self):
-        return hash(self.address)
+        """ E-mail addresses are case insensitive """
+        return hash(self.address.casefold())
 
     def __repr__(self):
         return self.__str__()
@@ -57,6 +64,22 @@ class Address(str):
     def address(self):
         return self._address
 
+    @property
+    def host(self):
+        """ XX Should it be part of Address.get? """
+        try:
+            return self._address.split("@")[1]
+        except IndexError:
+            return None
+
+    @property
+    def user(self):
+        """ XX docuemnt Should it be part of Address.get? """
+        try:
+            return self._address.split("@")[0]
+        except IndexError:
+            return None
+
     def get(self, name: bool = None, address: bool = None) -> str:
         """ Return `name` and/or `address`.
         Example:
@@ -154,7 +177,7 @@ class Attachment:
             m = magic.Magic(mime=True)
             mimetype = m.from_file(str(contents)) if isinstance(contents, Path) else m.from_buffer(contents)
 
-        self.data = data
+        self.data: bytes = data
         self.mimetype = mimetype
         self.name = name
         self.inline = inline
@@ -166,10 +189,10 @@ class Attachment:
         return f"Attachment({', '.join(l)})"
 
     def __str__(self):
-        return str(self.data)
+        return str(self.data, "utf-8")
 
     def __bytes__(self):
-        return bytes(self.data)
+        return self.data
 
     def get_sample(self):
         if self.data is None:
@@ -235,7 +258,7 @@ class _Message:
     def __str__(self):
         text, html = self.get()
         if text and html:
-            return " ".join("(text/plain)", text, "(text/html)", html)
+            return " ".join(("(text/plain)", text, "(text/html)", html))
         else:
             return text or html
 
